<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Eltávolítás a gyorsindítóról</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Ejtési hiba</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>A(z) „%1” fájl vagy URL nem ágyazható be a Gyorsindítóba</translation>
    </message>
</context>
</TS>